# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# __python2 macro defined from Fedora 16 onwards
# __python3 always defined where Python 3 is available, but this definition quietens rpmbuild when python3 is not installed
%{!?__python2: %global __python2 python2}
%{!?__python3: %global __python3 python3}

# Python3 introduced in Fedora 13, EPEL-7
%global with_python3 %([ "(" "%{__distinit}" == "fc" -o %{__distvers} -gt 6 ")" ] && echo 1 || echo 0)

# Python 2 dropped in Fedora 32, RHEL-8
%if %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -lt 32 ")" -o "(" "%{__distinit}" == "rhel" -a %{__distvers} -lt 8 ")" ] && echo 1 || echo 0)
%global with_python2 1
%global main_python  %{__python2}
%global other_python %{__python3}
%else
%global with_python2 0
%global main_python %{__python3}
%endif

# Single python3 version in Fedora, python3_pkgversion macro not available
%{!?python3_pkgversion:%global python3_pkgversion 3}

# For consistency and completeness
%global python2_pkgversion 2

# For -O3 on ppc64 (#1051068)
%global _performance_build 1

#global prerel rc1
%if %{with_python2}
%global python2ver %(%{__python2} -c "import sys; print sys.version[:3]" 2>/dev/null || echo none)
%endif
%if %{with_python3}
%global python3ver %(%{__python3} -c "import sys; print(sys.version[:3])" 2>/dev/null || echo none)
%endif

Summary:	Library providing XML and HTML support
Name:		libxml2
Version:	2.9.10
Release:	%{?prerel:0.}9.0.%{?prerel:%{prerel}.}cf.%{__distinit}%{__distvers}
License:	MIT
URL:		http://xmlsoft.org/
Source0:	ftp://xmlsoft.org/libxml2/libxml2-%{version}%{?prerel:-%{prerel}}.tar.gz
Patch0:		libxml2-multilib.patch
Patch1:		libxml2-2.9.8-python3-unicode-errors.patch
Patch2:		https://gitlab.gnome.org/GNOME/libxml2/commit/0815302dee2b78139832c2080348086a0564836b.patch#/fix-relaxed-approach-to-nested-documents.patch
Patch3:		libxml2-2.9.10-CVE-2019-20388.patch
Patch4:		libxml2-2.9.10-CVE-2020-7595.patch
Patch5:		libxml2-2.9.10-parenthesize-type-checks.patch
Patch6:		libxml2-2.9.10-fix-integer-overflow.patch
Patch7:		libxml2-2.9.10-CVE-2020-24977.patch
Patch8:		python-py_ssize_t.patch
Patch100:	libxml2-2.9.3-sles.patch
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	pkgconfig
%if %{with_python2}
BuildRequires:	python%{python2_pkgversion}, python%{python2_pkgversion}-devel
%endif
%if %{with_python3}
BuildRequires:	python%{python3_pkgversion}, python%{python3_pkgversion}-devel
%endif
BuildRequires:	sed
BuildRequires:	xz-devel%{?_isa}
BuildRequires:	zlib-devel%{?_isa}

# Don't drop bogus provide for python shared object as it's required by python-dmidecode (surely a packaging bug?)
#global __provides_exclude ^libxml2mod\\.so

%description
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub-nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package devel
Summary:	Libraries, includes, etc. to develop XML and HTML applications
Requires:	libxml2%{?_isa} = %{version}-%{release}
Requires:	pkgconfig
Requires:	xz-devel%{?_isa}
Requires:	zlib-devel%{?_isa}

%description devel
Libraries, include files, etc you can use to develop XML applications.
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub-nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package static
Summary:	Static library for libxml2
Requires:	libxml2-devel%{?_isa} = %{version}-%{release}

%description static
Static library for libxml2 provided for specific uses or shaving a few
microseconds when parsing, do not link to them for generic purpose packages.

%if %{with_python2}
%package -n python%{python2_pkgversion}-%{name}
Summary:	Python 2 bindings for the libxml2 library
Requires:	libxml2%{?_isa} = %{version}-%{release}
Obsoletes:	%{name}-python < %{version}-%{release}
Provides:	%{name}-python = %{version}-%{release}
Provides:	%{name}-python%{?_isa} = %{version}-%{release}
Obsoletes:	python-%{name} < %{version}-%{release}
Provides:	python-%{name} = %{version}-%{release}
Provides:	python-%{name}%{?_isa} = %{version}-%{release}

%description -n python2-%{name}
The python%{python2_pkgversion}-libxml2 package contains a Python 2 module that permits
applications written in the Python programming language, version 2, to use
the interface supplied by the libxml2 library to manipulate XML files.

This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DTDs, either
at parse time or later once the document has been modified.
%endif

%if %{with_python3}
%package -n python%{python3_pkgversion}-%{name}
Summary:	Python 3 bindings for the libxml2 library
Requires:	libxml2%{?_isa} = %{version}-%{release}
Obsoletes:	%{name}-python3 < %{version}-%{release}
Provides:	%{name}-python3 = %{version}-%{release}
Provides:	%{name}-python3%{?_isa} = %{version}-%{release}
%if "%{python3_pkgversion}" != "3"
Obsoletes:	python3-%{name} < %{version}-%{release}
Provides:	python3-%{name} = %{version}-%{release}
Provides:	python3-%{name}%{?_isa} = %{version}-%{release}
%endif

%description -n python%{python3_pkgversion}-%{name}
The python%{python3_pkgversion}-libxml2 package contains a Python 3 module that permits
applications written in the Python programming language, version 3, to use
the interface supplied by the libxml2 library to manipulate XML files.

This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DTDs, either
at parse time or later once the document has been modified.
%endif

# SuSE 10 needs this to build debuginfo
%if "%{__distinit}" == "sles"
%debug_package
%endif

%prep
%setup -q

# Avoid multilib file conflicts
%patch0 -p1

# Fix unicode errors in Python 3 (patch from openSUSE)
# https://bugzilla.gnome.org/show_bug.cgi?id=789714
%patch1 -p1

# Fix relaxed approach to nested documents on object disposal (#1780573)
%patch2 -p1

# Fix memory leak in xmlSchemaValidateStream
# CVE-2019-20388
# https://gitlab.gnome.org/GNOME/libxml2/merge_requests/68
%patch3 -p1

# Fix infinite loop in xmlStringLenDecodeEntities
# CVE-2020-7595
# https://gitlab.gnome.org/GNOME/libxml2/merge_requests/63
%patch4 -p1
 
# Parenthesize Py<type>_Check() in ifs for Python 3.9.0 support
# Upstream MR: https://gitlab.gnome.org/GNOME/libxml2/merge_requests/71
# Upstream issue: https://gitlab.gnome.org/GNOME/libxml2/issues/149
# Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=1808343
%patch5 -p1

# Fix integer overflow when comparing schema dates (CVE-2020-24977)
# https://bugzilla.redhat.com/show_bug.cgi?id=1877788
%patch6 -p1
%patch7 -p1

# Fix for Python 3.10 compatibility
# https://gitlab.gnome.org/GNOME/libxml2/-/merge_requests/87
# Don't want to apply this for ancient pythons though as it may break things
%if ! %{with_python2}
%patch8 -p1
# Remove files generated by python/generator.py to force regenerating them
rm python/{libxml2-py.c,libxml2-py.h,libxml2-export.c}
%endif

# Fix up docs paths for SLES
%if "%{__distinit}" == "sles"
%patch100 -b .sles
%endif

# Fix bogus exec permissions
find . \( -name '*.c' -o -name '*.py' \) -exec chmod -c 644 {} \;

# We'll ship compressed versions of some documentation
gzip -9c < doc/libxml2-api.xml > doc/libxml2-api.xml.gz

# make check / make runtests seem to have a failure on i386 on F-13 and similarly old releases
# similar to https://mail.gnome.org/archives/xml/2012-August/msg00025.html
%if "%{_arch}" == "i386" && 0%{?fedora} < 14 && 0%{?rhel} < 7
find . -name 'attr1.*' -delete
find . -name 'attr2.*' -delete
find . -name 'name2.*' -delete
%endif

# Create a separate source tree for the python3 build if necessary
%if 0%{?other_python:1} && %{with_python3} && 0%{?py3dir:1}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif

%if %{with_python3}
# Fix shellbangs on python3 examples
mkdir py3doc
cp -a doc/*.py py3doc
sed -i 's|#!/usr/bin/python |#!%{__python3} |' py3doc/*.py
%endif

%build
%configure --with-python=%{main_python}
make %{_smp_mflags} V=1

%if 0%{?other_python:1} && %{with_python3} && 0%{?py3dir:1}
pushd %{py3dir}
%configure --with-python=%{other_python}
make %{_smp_mflags} V=1
popd
%endif

%install
%if 0%{?other_python:1} && %{with_python3} && 0%{?py3dir:1}
# Do the python3 install first so that the python2 version is used
# for anything installed into the same locations
pushd %{py3dir}
make DESTDIR=%{buildroot} INSTALL="install -p" install
popd
%endif

make DESTDIR=%{buildroot} INSTALL="install -p" install

# Remove files we don't want packaged
rm -rf %{buildroot}%{_libdir}/*.la
%if %{with_python2}
rm -f %{buildroot}%{_libdir}/python%{python2ver}/site-packages/libxml2mod.{a,la}
%endif
%if %{with_python3}
rm -f %{buildroot}%{_libdir}/python%{python3ver}/site-packages/libxml2mod.{a,la}
%endif

# We'll package the documentation ourselves
rm -rf %{buildroot}%{_datadir}/doc/libxml2-%{version}/
rm -rf %{buildroot}%{_datadir}/doc/libxml2-python-%{version}/

# Multiarch crazyness on timestamp differences or Makefile/binaries for examples
touch -m --reference=%{buildroot}%{_includedir}/libxml2/libxml/parser.h %{buildroot}%{_bindir}/xml2-config
rm doc/examples/Makefile

%check
make runtests

%if 0%{?other_python:1} && %{with_python3} && 0%{?py3dir:1}
pushd %{py3dir}
# Workaround for this (python3 < 3.6?):
## ## running Python regression tests
## Traceback (most recent call last):
##   File "./reader2.py", line 55, in <module>
##     print(err)
## UnicodeEncodeError: 'ascii' codec can't encode character '\xe4' in position 79: ordinal not in range(128)
## -- reader2.py
## Error parsing and validating ../../test/valid/766956.xml
## Error parsing and validating ../../test/valid/cond_sect2.xml
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 25)
# https://stackoverflow.com/questions/2276200/changing-default-encoding-of-python
export PYTHONIOENCODING=utf8
%endif
make runtests
popd
%endif

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%if 0%{?_licensedir:1}
%license Copyright
%else
%doc Copyright
%endif
%doc AUTHORS NEWS README TODO
%{_bindir}/xmlcatalog
%{_bindir}/xmllint
%{_libdir}/libxml2.so.2*
%{_mandir}/man3/libxml.3*
%{_mandir}/man1/xmlcatalog.1*
%{_mandir}/man1/xmllint.1*

%files devel
%doc doc/*.html doc/html doc/*.gif doc/*.png
%doc doc/tutorial doc/libxml2-api.xml.gz
# Note: examples/writer.xml and examples/testWriter.c explicitly encoded as ISO-8859-1
%doc doc/examples
%doc %dir %{_datadir}/gtk-doc/html/libxml2/
%doc %{_datadir}/gtk-doc/html/libxml2/*.devhelp
%doc %{_datadir}/gtk-doc/html/libxml2/*.html
%doc %{_datadir}/gtk-doc/html/libxml2/*.png
%doc %{_datadir}/gtk-doc/html/libxml2/*.css
%{_libdir}/libxml2.so
%{_bindir}/xml2-config
%{_libdir}/xml2Conf.sh
%{_libdir}/cmake/libxml2/
%{_libdir}/pkgconfig/libxml-2.0.pc
%{_includedir}/libxml2/
%{_datadir}/aclocal/libxml.m4
%{_mandir}/man1/xml2-config.1*

%files static
%{_libdir}/libxml2.a

%if %{with_python2}
%files -n python%{python2_pkgversion}-%{name}
%doc python/TODO
%doc python/libxml2class.txt
%doc doc/*.py
%doc doc/python.html
%{_libdir}/python%{python2ver}/site-packages/libxml2.py*
%{_libdir}/python%{python2ver}/site-packages/drv_libxml2.py*
%{_libdir}/python%{python2ver}/site-packages/libxml2mod.so
%endif

%if %{with_python3}
%files -n python%{python3_pkgversion}-%{name}
%doc python/TODO
%doc python/libxml2class.txt
%doc py3doc/*.py
%doc doc/python.html
%{_libdir}/python%{python3ver}/site-packages/libxml2.py*
%{_libdir}/python%{python3ver}/site-packages/drv_libxml2.py*
%if "%{python3ver}" != "3.1"
%{_libdir}/python%{python3ver}/site-packages/__pycache__/libxml2.cpython-%(echo %{python3ver} | tr -d .)*.py*
%{_libdir}/python%{python3ver}/site-packages/__pycache__/drv_libxml2.cpython-%(echo %{python3ver} | tr -d .)*.py*
%endif
%{_libdir}/python%{python3ver}/site-packages/libxml2mod.so
%endif

%changelog
* Sat Nov 14 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-9.0.cf
- Add correct fix for CVE-2020-24977 (#1877788)
- Build the Python extension with the PY_SSIZE_T_CLEAN macro to make it
  compatible with Python 3.10 (#1890878)

* Sun Sep 13 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-7.0.cf
- Fix integer overflow when comparing schema dates (CVE-2020-24977)
  https://bugzilla.redhat.com/show_bug.cgi?id=1877788

* Tue Jul 28 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sun May 31 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-5.0.cf
- Rebuilt for Python 3.9

* Sat Feb 15 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-4.0.cf
- Fix memory leak in xmlSchemaValidateStream (CVE-2019-20388)
  https://gitlab.gnome.org/GNOME/libxml2/merge_requests/68
- Fix infinite loop in xmlStringLenDecodeEntities (CVE-2020-7595)
  https://gitlab.gnome.org/GNOME/libxml2/merge_requests/63
 
* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Jan  6 2020 Paul Howarth <paul@city-fan.org> - 2.9.10-2.0.cf
- Fix relaxed approach to nested documents on object disposal (#1780573)

* Tue Nov  5 2019 Paul Howarth <paul@city-fan.org> - 2.9.10-1.2.cf
- Avoid multilib conflict due to doc/examples/Makefile

* Mon Nov  4 2019 Paul Howarth <paul@city-fan.org> - 2.9.10-1.1.cf
- Fix unicode errors in Python 3, patch from openSUSE
  (see https://bugzilla.gnome.org/show_bug.cgi?id=789714)
- Drop old patches, no longer needed

* Thu Oct 31 2019 Paul Howarth <paul@city-fan.org> - 2.9.10-1.0.cf
- Update to 2.9.10
  - This is a relatively large release, fixing a number of bugs and improving
    the code in many areas, among other things removing some recursive
    behaviour of the code in various places
  - Includes various portability fixes, documentation updates and clean-ups
  - See https://mail.gnome.org/archives/xml/2019-October/msg00014.html for full
    details
- Drop python2 sub-package from F-32, EL-8 onwards
- Add workaround for test failures with python3 < 3.6

* Sat Oct  5 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-6.0.cf
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 26 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-5.0.cf
- Rebuilt for Python 3.8 in Rawhide

* Mon Aug 12 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Feb  4 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jan  4 2019 Paul Howarth <paul@city-fan.org> - 2.9.9-1.0.cf
- Update to 2.9.9
  - Security fixes, bug fixes as well as improvement and portability fixes for
    cygwin
  - Fix infinite loop in LZMA decompression (CVE-2018-9251, CVE-2018-14567)
  - Fix nullptr deref with XPath logic ops (CVE-2018-14404)
  - See https://mail.gnome.org/archives/xml/2019-January/msg00000.html for full
    details

* Mon Aug 13 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-4.0.cf
- Various backports from upstream

* Mon Jul 16 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-2.0.cf
- Rebuild for Python 3.7 in Rawhide

* Wed Mar  7 2018 Paul Howarth <paul@city-fan.org> - 2.9.8-1.0.cf
- Update to 2.9.8
  - Bug fix and enhancement update
  - See https://mail.gnome.org/archives/xml//2018-March/msg00001.html
- Fix test compatibility with Python 3

* Fri Mar  2 2018 Paul Howarth <paul@city-fan.org> - 2.9.7-4.0.cf
- Rebuild with new LDFLAGS from redhat-rpm-config

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 2.9.7-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Feb  5 2018 Paul Howarth <paul@city-fan.org> - 2.9.7-2.0.cf
- Make the XML entity recursion check more precise (CVE-2016-9597)
- Drop ldconfig scriptlets from Fedora 28 onwards
- Enable python3 sub-package for EL-7 builds
- Static library depends on devel package, not base package
- %%{?_isa} always available
- Make %%files list more explicit

* Fri Nov  3 2017 Paul Howarth <paul@city-fan.org> - 2.9.7-1.0.cf
- Update to 2.9.7
  - Bug fix, portability and enhancement update
  - See https://mail.gnome.org/archives/xml/2017-November/msg00001.html

* Fri Oct  6 2017 Paul Howarth <paul@city-fan.org> - 2.9.6-1.0.cf
- Update to 2.9.6
  - Bug fix update
  - See https://mail.gnome.org/archives/xml/2017-October/msg00003.html

* Wed Sep 20 2017 Paul Howarth <paul@city-fan.org> - 2.9.5-2.0.cf
- Report undefined XPath variable error message (#1493613, Gnome Bug #787941)

* Tue Sep  5 2017 Paul Howarth <paul@city-fan.org> - 2.9.5-1.0.cf
- Update to 2.9.5
  - Many bug fixes, including security issues
  - See https://mail.gnome.org/archives/xml/2017-September/msg00000.html

* Tue Aug 22 2017 Paul Howarth <paul@city-fan.org> - 2.9.4-5.0.cf
- Python 2 binary package renamed to python2-libxml2
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 2.9.4-4.0.cf
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Feb 11 2017 Paul Howarth <paul@city-fan.org> - 2.9.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Dec 24 2016 Paul Howarth <paul@city-fan.org> - 2.9.4-1.1.cf
- Apply very hacky patch that removes the PyVerify_fd symbol, not available in
  Python 3.6

* Tue May 24 2016 Paul Howarth <paul@city-fan.org> - 2.9.4-1.0.cf
- Update to 2.9.4
  - This is a big release, including a number of security patches, and there
    are also a significant number of 'normal' bug fixes and a fair number of
    portability fixes including a massive patch set for OS400
  - See https://mail.gnome.org/archives/xml/2016-May/msg00023.html
- Add patch to fix attribute decoding during XML schema validation
  (https://bugzilla.gnome.org/show_bug.cgi?id=766834)
- Simplify find commands using -delete

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 2.9.3-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Dec  3 2015 Paul Howarth <paul@city-fan.org> - 2.9.3-2.0.cf
- Fix obsoletes versions now that F22 has libxml2 2.9.3 (#1287262)

* Tue Nov 24 2015 Paul Howarth <paul@city-fan.org> - 2.9.3-1.0.cf
- Update to 2.9.3
  - CVE-2015-1819 Enforce the reader to run in constant memory
  - CVE-2015-5312 Another entity expansion issue
  - CVE-2015-7497 Avoid an heap buffer overflow in xmlDictComputeFastQKey
  - CVE-2015-7498 Avoid processing entities after encoding conversion failures
  - CVE-2015-7941-1 Stop parsing on entities boundaries errors
  - CVE-2015-7941-2 Cleanup conditional section error handling
  - CVE-2015-7942-1 Another variation of overflow in Conditional sections
  - CVE-2015-7942-2 Fix an error in previous Conditional section patch
  - CVE-2015-7499-1 Add xmlHaltParser() to stop the parser
  - CVE-2015-7499-2 Detect incoherency on GROW
  - CVE-2015-7500 Fix memory access error due to incorrect entities boundaries
  - CVE-2015-8035 Fix XZ compression support loop
  - CVE-2015-8242 Buffer overead with HTML parser in push mode
  - Various other bug fixes
    (see https://mail.gnome.org/archives/xml/2015-November/msg00012.html)
- Update SLES paths patch

* Sat Nov 14 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-9.0.cf
- Rebuild for Python 3.5 in Rawhide

* Mon Aug 31 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-7.0.cf
- Rename the Python 3 subpackage to python3-libxml2 as per guidelines

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-4.0.cf
- Rebuilt for Fedora 23 Change
  https://fedoraproject.org/wiki/Changes/Harden_all_packages_with_position-independent_code

* Fri Feb 20 2015 Paul Howarth <paul@city-fan.org> - 2.9.2-3.0.cf
- Add a python3 sub-package where possible

* Thu Dec 11 2014 Paul Howarth <paul@city-fan.org> - 2.9.2-2.1.cf
- Don't drop bogus (not in %%{_libdir}) provide for python shared object as
  it's required by python-dmidecode (surely a packaging bug?)

* Mon Oct 20 2014 Paul Howarth <paul@city-fan.org> - 2.9.2-2.0.cf
- Avoid corrupting the xml catalogs (#1153753)

* Fri Oct 17 2014 Paul Howarth <paul@city-fan.org> - 2.9.2-1.0.cf
- Update to 2.9.2
- Drop upstreamed patches
- Work around test issue on old 32-bit builds by dropping the test
- Run make in verbose mode so we can see which compiler flags were used

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 2.9.1-5.1.cf
- Use %%license where possible

* Mon Apr 28 2014 Paul Howarth <paul@city-fan.org> - 2.9.1-5.0.cf
- Enable xz compression support
- Fix a regression in xmlGetDocCompressMode() (#963716)
- Activate -O3 on ppc64 (#1051068)
- Drop support for old distributions prior to FC-5
  - Drop python 2.3 support
  - Drop %%defattr, redundant since rpm 4.4

* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> - 2.9.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> - 2.9.1-1.0.cf
- Update to 2.9.1
  - A couple more API entry points
  - Compatibility with python3
  - A lot of bug fixes
- Maintain timestamps where possible
- Add patch to fix python 2.6 compatibility (Gnome Bug #698364)
- Update patch for python 2.3 compatibility

* Mon Feb 11 2013 Paul Howarth <paul@city-fan.org> - 2.9.0-4.0.cf
- Don't ship examples/.deps in devel package

* Mon Nov 19 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-3.0.cf
- workaround for crc/len check failure (#877567)

* Thu Oct 11 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-2.0.cf
- Only ship the library documentation in the -devel package, not the main
  package (#864731)
- Don't ship the old ChangeLog file

* Tue Sep 11 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-1.0.cf
- Update to 2.9.0 final
  - A few new API entry points
  - More resilient push parser mode
  - A lot of portability improvements
  - Faster XPath evaluation
  - A lot of bug fixes and smaller improvements

* Sun Aug 19 2012 Paul Howarth <paul@city-fan.org> - 2.9.0-0.1.0.rc1.cf
- Upstream release candidate 1 of 2.9.0
  - Introduce a small API change, but ABI compatible, see
    https://mail.gnome.org/archives/xml/2012-August/msg00005.html
  - Patches for php, gcc/libjava and evolution-data-connector are upstream
  - In case of problems, contact Daniel Veillard <veillard@redhat.com>
  - Many bug fixes including security aspects and small improvements

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 2.8.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 23 2012 Paul Howarth <paul@city-fan.org> - 2.8.0-1.0.cf
- New release 2.8.0
  - Add lzma compression support
  - Various documentation updates
  - Lots of portability fixes, particularly for Windows targets
  - Lots of bug fixes and other improvements
- Drop patches no longer needed
- Add %%clean section and run the test suite there
- Drop support for python 2.2

* Fri Jan 13 2012 Paul Howarth <paul@city-fan.org> - 2.7.8-10.0.cf
- Add XPath hardening patch from upstream (#732335)
- Fix missing error status in XPath evaluation (CVE-2011-2834)
- Make sure the parser returns when getting a Stop order (CVE-2011-3905)
- Fix an allocation error when copying entities (CVE-2011-3919)

* Wed Nov 16 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-9.0.cf
- Fix a heap-based buffer overflow caused by an off by one error in the
  encoding code (#724906, CVE-2011-0216)

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-8.0.cf
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-7.0.cf
- Fix a heap-based buffer overflow caused by adding a new namespace node to an
  existing nodeset or merging nodesets in XPath (#709750, CVE-2011-1944)
- Drop bogus provide for python shared object
- Nobody else likes macros for commands

* Fri Mar  4 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-6.0.cf
- Fix a double free in XPath (#665965, CVE-2010-4494)

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> - 2.7.8-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Nov  5 2010 Paul Howarth <paul@city-fan.org> - 2.7.8-4.0.cf
- Resync with Rawhide

* Thu Nov  4 2010 Paul Howarth <paul@city-fan.org> - 2.7.8-2.0.cf
- New release 2.7.8
  - Various bug fixes, including potential crashes
  - New non-destructive formatting option
  - Date parsing updated to RFC 5646
- Add patch to fix shared library versioning
- Add patch to support build of python bindings with python < 2.4

* Wed Jul 28 2010 Paul Howarth <paul@city-fan.org> - 2.7.7-2.1.cf
- Rebuild for python 2.7 in Rawhide

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 2.7.7-2.0.cf
- Fix dist tag for RHEL-6 Beta

* Mon Mar 15 2010 Paul Howarth <paul@city-fan.org> - 2.7.7-1.0.cf
- New release 2.7.7
  - Fix serious trouble with zlib >= 1.2.4
  - xmllint new option --xpath
  - Various HTML parser improvements
  - Includes a number of bug fixes

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> - 2.7.6-2.0.cf
- dist tag for Rawhide no longer needs special-casing

* Wed Oct  7 2009 Paul Howarth <paul@city-fan.org> - 2.7.6-1.0.cf
- New release 2.7.6 (restore thread support off by default in 2.7.5)

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> - 2.7.5-1.0.cf
- New release 2.7.5
  - Little data at startup patch upstreamed
  - Fix a couple of Relax-NG validation problems
  - A few more fixes

* Tue Sep 15 2009 Paul Howarth <paul@city-fan.org> - 2.7.4-2.0.cf
- Fix a problem with little data at startup affecting inkscape (#523002)

* Thu Sep 10 2009 Paul Howarth <paul@city-fan.org> - 2.7.4-1.0.cf
- New release 2.7.4, with security patches now upstream
- Lots of other fixes: see http://xmlsoft.org/news.html
- Update SLES patch to remove fuzz

* Wed Aug 12 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-4.0.cf
- Two patches for parsing problems CVE-2009-2414 and CVE-2009-2416

* Fri Jul 31 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 24 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-1.2.cf
- Force creation of debuginfo on SLES

* Mon Feb 23 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-1.1.cf
- Add SLES support in dist tag macros
- Add patch to fix up docs directories for SLES

* Tue Jan 20 2009 Paul Howarth <paul@city-fan.org> - 2.7.3-1.0.CF
- New release 2.7.3, with security patches now upstream
- Limit default max size of text nodes
- Special parser mode for PHP
- Bug fixes and more compiler checks
- Source is now in "libxml2" directory on ftp server at xmlsoft.org

* Wed Dec 10 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-7.0.CF
- Rebuild for python 2.6 on Rawhide

* Wed Dec  3 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-6.0.CF
- Buildreq pkgconfig to get pkgconfig auto-provides (#473978)

* Mon Nov 17 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-3
- Two patches for size overflow problems: CVE-2008-4225 (#470480) and
  CVE-2008-4226 (#470466)

* Fri Oct 31 2008 Paul Howarth <paul@city-fan.org> - 2.7.2-2
- Import from Fedora
- Make subpackages package require same-arch version of base package
- Use full pathnames for build-time command paths
- Install using DESTDIR rather than deprecated %%makeinstall macro
- Remove bogus exec permissions from source files
- Don't package static python binding

* Fri Oct  3 2008 Daniel Veillard <veillard@redhat.com> - 2.7.2-1.fc10
- New release 2.7.2
- Fixes the known problems in 2.7.1
- Increase the set of options when saving documents

* Thu Oct  2 2008 Daniel Veillard <veillard@redhat.com> - 2.7.1-2.fc10
- Fix a nasty bug in 2.7.x, http://bugzilla.gnome.org/show_bug.cgi?id=554660

* Mon Sep  1 2008 Daniel Veillard <veillard@redhat.com> - 2.7.1-1.fc10
- Fix python serialization which was broken in 2.7.0
- Resolve: rhbz#460774

* Sat Aug 30 2008 Daniel Veillard <veillard@redhat.com> - 2.7.0-1.fc10
- Upstream release of 2.7.0
- Switch to XML 1.0 5th edition
- Switch to RFC 3986 for URI parsing
- better entity handling
- Option to remove hardcoded limitations in the parser
- More testing
- A new API to allocate entity nodes
- And lot of fixes and clanups

* Mon Aug 25 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-4.fc10
- Fix for entities recursion problem
- Resolve: rhbz#459714

* Fri May 30 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-3.fc10
- Cleanup based on Fedora packaging guidelines, should fix #226079
- Separate a -static package

* Thu May 15 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-2.fc10
- Try to fix multiarch problems like #440206

* Tue Apr  8 2008 Daniel Veillard <veillard@redhat.com> - 2.6.32-1.fc9
- Upstream release 2.6.32 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.6.31-2
- Autorebuild for GCC 4.3

* Fri Jan 11 2008 Daniel Veillard <veillard@redhat.com> - 2.6.31-1.fc9
- Upstream release 2.6.31 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Thu Aug 23 2007 Daniel Veillard <veillard@redhat.com> - 2.6.30-1
- Upstream release 2.6.30 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Tue Jun 12 2007 Daniel Veillard <veillard@redhat.com> - 2.6.29-1
- Upstream release 2.6.29 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Wed May 16 2007 Matthias Clasen <mclasen@redhat.com> - 2.6.28-2
- Bump revision to fix N-V-R problem

* Tue Apr 17 2007 Daniel Veillard <veillard@redhat.com> - 2.6.28-1
- Upstream release 2.6.28 see http://xmlsoft.org/news.html
- Many bug fixed upstream

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 2.6.27-2
- Rebuild against python 2.5

* Wed Oct 25 2006 Daniel Veillard <veillard@redhat.com> - 2.6.27-1
- Upstream release 2.6.27 see http://xmlsoft.org/news.html
- Very large amount of bug fixes reported upstream

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.6.26-2.1.1
- Rebuild

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.6.26-2.1
- Rebuild

* Wed Jun  7 2006 Daniel Veillard <veillard@redhat.com> - 2.6.26-2
- Fix bug #192873

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com> - 2.6.26-1
- Upstream release 2.6.26 see http://xmlsoft.org/news.html

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com>
- Upstream release 2.6.25 broken, do not ship!

